@@ -25,6 +25,7 @@ sub _build_decoder_json {
 
 sub encode_objects {
   my ($self, $data) = @_;
+  no warnings 'once';
   local *UNIVERSAL::TO_JSON = sub { $self->deflate($_[0]) };
   decode_json($self->encoder_json->encode($data));
 }
@@ -34,3 +35,4 @@ sub decode_objects {
   $self->decoder_json->decode(encode_json($data));
 }
 
+1;
